@@ -4,6 +4,8 @@ dispMUA.arDispMUAAllocation["1"] =
   "1blu webmail" : [ "1blu_de.png" , "http://www.1blu.de/" ] ,
   "1&1 webmail" : [ "1und1.png" , "http://www.1und1.de/" ] ,
   "1st news" : [ "1st-news.png" , "http://www.1st-scripts.de/" ] ,
+  "1&1 voip" : [ "1und1.png" , "http://www.1und1.de/" ] ,
+  "1&1 mail" : [ "1und1.png" , "http://www.1und1.de/" ] ,
   "126com" : [ "126_com.png" , "http://www.126.com/" ] ,
   "12all" : [ "12all.png" , "http://activecampaign.com/12all/" ] ,
 }
